nxp-pac

Crates

git

Versions

mcxa577

Flavors

Ctrl1

Struct Ctrl1 

#[repr(transparent)]
pub struct Ctrl1(pub u32);
Control Register 1 SFR

Tuple Fields

0: u32

Implementations

Source

impl Ctrl1

pub const fn read_index(&self) -> u8

Index status, Writing an index value to this register will request the block to return the lock status of this index.

pub const fn set_read_index(&mut self, val: u8)

Index status, Writing an index value to this register will request the block to return the lock status of this index.

pub const fn reserved15(&self) -> u8

Reserved for Future Use

pub const fn set_reserved15(&mut self, val: u8)

Reserved for Future Use

pub const fn wr_en_1(&self) -> u8

Write Enable One

pub const fn set_wr_en_1(&mut self, val: u8)

Write Enable One

pub const fn sfr_lock(&self) -> u8

LOCK register for GLIKEY

pub const fn set_sfr_lock(&mut self, val: u8)

LOCK register for GLIKEY

pub const fn reserved31(&self) -> u16

Reserved for Future Use

pub const fn set_reserved31(&mut self, val: u16)

Reserved for Future Use