#[repr(transparent)]pub struct IntrCtrl(pub u32);Expand description
Interrupt Control
Tuple Fields
0: u32Implementations
Sourceimpl IntrCtrl
impl IntrCtrl
Sourcepub const fn int_en(&self) -> bool
pub const fn int_en(&self) -> bool
Interrupt Enable. Writing a 1, Interrupt asserts on Interrupt output port
Sourcepub const fn set_int_en(&mut self, val: bool)
pub const fn set_int_en(&mut self, val: bool)
Interrupt Enable. Writing a 1, Interrupt asserts on Interrupt output port
Sourcepub const fn int_clr(&self) -> bool
pub const fn int_clr(&self) -> bool
Interrupt Clear. Writing a 1 to this register creates a single interrupt clear pulse. This register reads as 0
Sourcepub const fn set_int_clr(&mut self, val: bool)
pub const fn set_int_clr(&mut self, val: bool)
Interrupt Clear. Writing a 1 to this register creates a single interrupt clear pulse. This register reads as 0
Sourcepub const fn int_set(&self) -> bool
pub const fn int_set(&self) -> bool
Interrupt Set. Writing a 1 to this register asserts the interrupt. This register reads as 0
Sourcepub const fn set_int_set(&mut self, val: bool)
pub const fn set_int_set(&mut self, val: bool)
Interrupt Set. Writing a 1 to this register asserts the interrupt. This register reads as 0
Sourcepub const fn reserved31(&self) -> u32
pub const fn reserved31(&self) -> u32
Reserved for Future Use
Sourcepub const fn set_reserved31(&mut self, val: u32)
pub const fn set_reserved31(&mut self, val: u32)
Reserved for Future Use